import getpass
from tempfile import mkdtemp

# Test if we are running in a docker
if getpass.getuser() == "jovyan":
    c.ServerApp.ip = "0.0.0.0"

c.ServerApp.port = 8888
c.ServerApp.port_retries = 0
c.ServerApp.open_browser = False
c.LabApp.dev_mode = True

c.ServerApp.root_dir = mkdtemp(prefix="galata-test-")
c.ServerApp.token = ""
c.ServerApp.password = ""
c.ServerApp.disable_check_xsrf = True
c.LabApp.expose_app_in_browser = True



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# JupyterLab documentation build configuration file, created by
# sphinx-quickstart on Thu Jan  4 15:10:23 2018.
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))

import os
import os.path as osp
import shutil
from subprocess import check_call

HERE = osp.abspath(osp.dirname(__file__))

# -- General configuration ------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ["myst_parser", "sphinx.ext.intersphinx", "sphinx.ext.mathjax", "sphinx_copybutton"]

myst_enable_extensions = ["html_image"]
myst_heading_anchors = 3

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# The file extensions of source files.
# Sphinx considers the files with this suffix as sources.
# The value can be a dictionary mapping file extensions to file types.
source_suffix = {".rst": "restructuredtext", ".md": "markdown"}

# The master toctree document.
master_doc = "index"

# General information about the project.
project = "JupyterLab"
copyright = "2018, Project Jupyter"
author = "Project Jupyter"


# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.

_version_py = osp.join(HERE, "..", "..", "jupyterlab", "_version.py")
version_ns = {}

with open(_version_py, mode="r") as version_file:
    exec(version_file.read(), version_ns)

# The short X.Y version.
version = "%i.%i" % version_ns["version_info"][:2]
# The full version, including alpha/beta/rc tags.
release = version_ns["__version__"]


# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = "en"

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = []

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = False


# build js docs and stage them to the build directory
def build_api_docs(out_dir):
    """build js api docs"""
    docs = osp.join(HERE, os.pardir)
    root = osp.join(docs, os.pardir)
    docs_api = osp.join(docs, "api")
    api_index = osp.join(docs_api, "index.html")
    # is this an okay way to specify jlpm
    # without installing jupyterlab first?
    jlpm = ["node", osp.join(root, "jupyterlab", "staging", "yarn.js")]

    if osp.exists(api_index):
        # avoid rebuilding docs because it takes forever
        # `make clean` to force a rebuild
        print(f"already have {api_index}")
    else:
        print("Building jupyterlab API docs")
        check_call(jlpm, cwd=root)
        check_call(jlpm + ["build:packages"], cwd=root)
        check_call(jlpm + ["docs"], cwd=root)

    dest_dir = osp.join(out_dir, "api")
    print(f"Copying {docs_api} -> {dest_dir}")
    if osp.exists(dest_dir):
        shutil.rmtree(dest_dir)
    shutil.copytree(docs_api, dest_dir)


# Copy frontend files for snippet inclusion
FILES_LIST = [  # File paths should be relative to jupyterlab root folder
    "packages/settingregistry/src/plugin-schema.json"
]
SNIPPETS_FOLDER = "snippets"


def copy_code_files(temp_folder):
    """Copy files in the temp_folder"""
    docs = osp.join(HERE, os.pardir)
    root = osp.join(docs, os.pardir)

    for file in FILES_LIST:
        target = osp.join(temp_folder, file)
        if not osp.exists(osp.dirname(target)):
            os.makedirs(osp.dirname(target), exist_ok=True)
        shutil.copyfile(osp.join(root, file), target)


# -- Options for HTML output ----------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
import sphinx_rtd_theme

html_theme = "sphinx_rtd_theme"
html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#
# html_theme_options = {}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]

# Custom sidebar templates, must be a dictionary that maps document names
# to template names.
#
# This is required for the alabaster theme
# refs: http://alabaster.readthedocs.io/en/latest/installation.html#sidebars
html_sidebars = {
    "**": [
        "about.html",
        "navigation.html",
        "relations.html",  # needs 'show_related': True theme option to display
        "searchbox.html",
        "donate.html",
    ]
}

# Output for github to be used in links
html_context = {
    "display_github": True,  # Integrate GitHub
    "github_user": "jupyterlab",  # Username
    "github_repo": "jupyterlab",  # Repo name
    "github_version": "3.5.x",  # Version
    "conf_py_path": "/docs/source/",  # Path in the checkout to the docs root
}

# -- Options for HTMLHelp output ------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = "JupyterLabdoc"


# -- Options for LaTeX output ---------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    # 'papersize': 'letterpaper',
    # The font size ('10pt', '11pt' or '12pt').
    #
    # 'pointsize': '10pt',
    # Additional stuff for the LaTeX preamble.
    #
    # 'preamble': '',
    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto, manual, or own class]).
latex_documents = [
    (master_doc, "JupyterLab.tex", "JupyterLab Documentation", "Project Jupyter", "manual"),
]


# -- Options for manual page output ---------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [(master_doc, "jupyterlab", "JupyterLab Documentation", [author], 1)]


# -- Options for Texinfo output -------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (
        master_doc,
        "JupyterLab",
        "JupyterLab Documentation",
        author,
        "JupyterLab",
        "One line description of project.",
        "Miscellaneous",
    ),
]


# -- Options for Epub output ----------------------------------------------

# Bibliographic Dublin Core info.
epub_title = project
epub_author = author
epub_publisher = author
epub_copyright = copyright

# The unique identifier of the text. This can be a ISBN number
# or the project homepage.
#
# epub_identifier = ''

# A unique identification for the text.
#
# epub_uid = ''

# A list of files that should not be packed into the epub file.
epub_exclude_files = ["search.html"]


# Example configuration for intersphinx: refer to the Python standard library.
intersphinx_mapping = {"https://docs.python.org/": None}


def setup(app):
    dest = osp.join(HERE, "getting_started/changelog.md")
    shutil.copy(osp.join(HERE, "..", "..", "CHANGELOG.md"), dest)
    app.add_css_file("css/custom.css")  # may also be an URL
    build_api_docs(app.outdir)

    copy_code_files(osp.join(app.srcdir, SNIPPETS_FOLDER))

    def clean_code_files(app, exception):
        """Remove temporary folder."""
        try:
            shutil.rmtree(osp.join(app.srcdir, SNIPPETS_FOLDER))
        except Exception as e:
            print(f"Fail to remove temporary snippet folder: {e}")

    app.connect("build-finished", clean_code_files)



import json
import os
import os.path as osp
import shutil
import subprocess
import sys
from pathlib import Path

import pkg_resources

try:
    from cookiecutter.main import cookiecutter
except ImportError:
    raise RuntimeError("Please install cookiecutter")


DEFAULT_COOKIECUTTER_BRANCH = "3.0"


def update_extension(target, branch=DEFAULT_COOKIECUTTER_BRANCH, interactive=True):
    """Update an extension to the current JupyterLab

    target: str
        Path to the extension directory containing the extension
    branch: str [default: DEFAULT_COOKIECUTTER_BRANCH]
        Template branch to checkout
    interactive: bool [default: true]
        Whether to ask before overwriting content

    """
    # Input is a directory with a package.json or the current directory
    # Use the cookiecutter as the source
    # Pull in the relevant config
    # Pull in the Python parts if possible
    # Pull in the scripts if possible
    target = osp.abspath(target)
    package_file = osp.join(target, "package.json")
    setup_file = osp.join(target, "setup.py")
    if not osp.exists(package_file):
        raise RuntimeError("No package.json exists in %s" % target)

    # Infer the options from the current directory
    with open(package_file) as fid:
        data = json.load(fid)

    if osp.exists(setup_file):
        python_name = (
            subprocess.check_output([sys.executable, "setup.py", "--name"], cwd=target)
            .decode("utf8")
            .strip()
        )
    else:
        python_name = data["name"]
        if "@" in python_name:
            python_name = python_name[1:].replace("/", "_").replace("-", "_")

    output_dir = osp.join(target, "_temp_extension")
    if osp.exists(output_dir):
        shutil.rmtree(output_dir)

    # Build up the cookiecutter args and run the cookiecutter
    extra_context = dict(
        author_name=data.get("author", "<author_name>"),
        labextension_name=data["name"],
        project_short_description=data.get("description", "<description>"),
        has_server_extension="y" if osp.exists(osp.join(target, "jupyter-config")) else "n",
        has_binder="y" if osp.exists(osp.join(target, "binder")) else "n",
        repository=data.get("repository", {}).get("url", "<repository"),
        python_name=python_name,
    )

    template = "https://github.com/jupyterlab/extension-cookiecutter-ts"
    cookiecutter(
        template=template,
        checkout=branch,
        output_dir=output_dir,
        extra_context=extra_context,
        no_input=not interactive,
    )

    python_name = os.listdir(output_dir)[0]

    # hoist the output up one level
    shutil.move(osp.join(output_dir, python_name), osp.join(output_dir, "_temp"))
    for filename in os.listdir(osp.join(output_dir, "_temp")):
        shutil.move(osp.join(output_dir, "_temp", filename), osp.join(output_dir, filename))
    shutil.rmtree(osp.join(output_dir, "_temp"))

    # Check whether there are any phosphor dependencies
    has_phosphor = False
    for name in ["devDependencies", "dependencies"]:
        if name not in data:
            continue

        for (key, value) in list(data[name].items()):
            if key.startswith("@phosphor/"):
                has_phosphor = True
                data[name][key.replace("@phosphor/", "@lumino/")] = value

        for key in list(data[name]):
            if key.startswith("@phosphor/"):
                del data[name][key]

    # From the created package.json grab the devDependencies
    with open(osp.join(output_dir, "package.json")) as fid:
        temp_data = json.load(fid)

    if data.get("devDependencies"):
        for (key, value) in temp_data["devDependencies"].items():
            data["devDependencies"][key] = value
    else:
        data["devDependencies"] = temp_data["devDependencies"].copy()

    # Ask the user whether to upgrade the scripts automatically
    warnings = []
    if interactive:
        choice = input("overwrite scripts in package.json? [n]: ")
    else:
        choice = "y"
    if choice.upper().startswith("Y"):
        warnings.append("Updated scripts in package.json")
        data.setdefault("scripts", dict())
        for (key, value) in temp_data["scripts"].items():
            data["scripts"][key] = value
        if "install-ext" in data["scripts"]:
            del data["scripts"]["install-ext"]
    else:
        warnings.append("package.json scripts must be updated manually")

    # Set the output directory
    data["jupyterlab"]["outputDir"] = temp_data["jupyterlab"]["outputDir"]

    # Look for resolutions in JupyterLab metadata and upgrade those as well
    root_jlab_package = pkg_resources.resource_filename("jupyterlab", "staging/package.json")
    with open(root_jlab_package) as fid:
        root_jlab_data = json.load(fid)

    data.setdefault("dependencies", dict())
    data.setdefault("devDependencies", dict())
    for (key, value) in root_jlab_data["resolutions"].items():
        if key in data["dependencies"]:
            data["dependencies"][key] = value.replace("~", "^")
        if key in data["devDependencies"]:
            data["devDependencies"][key] = value.replace("~", "^")

    # Sort the entries
    for key in ["scripts", "dependencies", "devDependencies"]:
        if data[key]:
            data[key] = dict(sorted(data[key].items()))
        else:
            del data[key]

    # Update style settings
    data.setdefault("styleModule", "style/index.js")
    if isinstance(data.get("sideEffects"), list) and "style/index.js" not in data["sideEffects"]:
        data["sideEffects"].append("style/index.js")
    if "files" in data and "style/index.js" not in data["files"]:
        data["files"].append("style/index.js")

    # Update the root package.json file
    with open(package_file, "w") as fid:
        json.dump(data, fid, indent=2)

    # For the other files, ask about whether to override (when it exists)
    # At the end, list the files that were: added, overridden, skipped
    path = Path(output_dir)
    for p in path.rglob("*"):
        relpath = osp.relpath(p, path)
        if relpath == "package.json":
            continue
        if p.is_dir():
            continue
        file_target = osp.join(target, relpath)
        if not osp.exists(file_target):
            os.makedirs(osp.dirname(file_target), exist_ok=True)
            shutil.copy(p, file_target)
        else:
            with open(p, "rb") as fid:
                old_data = fid.read()
            with open(file_target, "rb") as fid:
                new_data = fid.read()
            if old_data == new_data:
                continue
            if interactive:
                choice = input('overwrite "%s"? [n]: ' % relpath)
            else:
                choice = "n"
            if choice.upper().startswith("Y"):
                shutil.copy(p, file_target)
            else:
                warnings.append("skipped _temp_extension/%s" % relpath)

    # Print out all warnings
    for warning in warnings:
        print("**", warning)

    print("** Remove _temp_extensions directory when finished")

    if has_phosphor:
        print(
            "** Phosphor dependencies were upgraded to lumino dependencies, update imports as needed"
        )


if __name__ == "__main__":
    import argparse

    parser = argparse.ArgumentParser(description="Upgrade a JupyterLab extension")

    parser.add_argument("--no-input", action="store_true", help="whether to prompt for information")

    parser.add_argument("path", action="store", type=str, help="the target path")

    parser.add_argument(
        "--branch", help="the template branch to checkout", default=DEFAULT_COOKIECUTTER_BRANCH
    )

    args = parser.parse_args()

    update_extension(args.path, args.branch, args.no_input == False)



# Copyright (c) Jupyter Development Team.
# Distributed under the terms of the Modified BSD License.

import argparse
import hashlib
import json
import shutil
from pathlib import Path

parser = argparse.ArgumentParser(description="Update Galata Snapshot images.")
parser.add_argument("report", help="Path to the galata-report directory")
args = parser.parse_args()

# Calculate hashes of all png files in the test/directory
def sha1(path):
    with open(path, "rb") as f:
        return hashlib.sha1(f.read()).hexdigest()


filehashes = {sha1(p): p for p in Path(".").glob("**/*-snapshots/*-linux.png")}


# For every json file in data directory except report.json
data_dir = Path(args.report).expanduser().resolve() / "data"
for p in data_dir.glob("*.json"):
    if p.name == "report.json":
        continue
    with open(p, "rb") as f:
        z = json.load(f)
    for t in z["tests"]:
        if t["outcome"] != "unexpected":
            continue
        for r in t["results"]:
            for attachment in r["attachments"]:
                if attachment["name"] == "expected":
                    expected = Path(attachment["path"]).stem
                elif attachment["name"] == "actual":
                    actual = data_dir / Path(attachment["path"]).name
            if expected and attachment and expected in filehashes:
                shutil.copyfile(actual, filehashes[expected])
                print(f"{actual} -> {filehashes[expected]}")



#!/usr/bin/env python
# coding: utf-8

import json
import os
import os.path as osp
import subprocess
import sys

# Copyright (c) Jupyter Development Team.
# Distributed under the terms of the Modified BSD License.
from os.path import join as pjoin

from setuptools import setup

NAME = "jupyterlab"
HERE = osp.dirname(osp.abspath(__file__))

ensured_targets = [
    "static/package.json",
    "schemas/@jupyterlab/shortcuts-extension/shortcuts.json",
    "themes/@jupyterlab/theme-light-extension/index.css",
]
ensured_targets = [osp.join(HERE, NAME, t) for t in ensured_targets]

data_files_spec = [
    ("share/jupyter/lab/static", f"{NAME}/static", "**"),
    ("share/jupyter/lab/schemas", f"{NAME}/schemas", "**"),
    ("share/jupyter/lab/themes", f"{NAME}/themes", "**"),
    (
        "etc/jupyter/jupyter_server_config.d",
        "jupyter-config/jupyter_server_config.d",
        f"{NAME}.json",
    ),
    (
        "etc/jupyter/jupyter_notebook_config.d",
        "jupyter-config/jupyter_notebook_config.d",
        f"{NAME}.json",
    ),
]


def post_dist():
    from jupyter_packaging import get_version
    from packaging.version import Version

    target = pjoin(HERE, NAME, "static", "package.json")
    with open(target) as fid:
        version = json.load(fid)["jupyterlab"]["version"]

    if Version(version) != Version(get_version(f"{NAME}/_version.py")):
        raise ValueError("Version mismatch, please run `build:update`")


try:
    from jupyter_packaging import get_data_files, npm_builder, wrap_installers

    npm = ["node", pjoin(HERE, NAME, "staging", "yarn.js")]
    # In develop mode, just run yarn, unless this is an sdist.
    if os.path.exists(os.path.join(HERE, "buildutils")):
        builder = npm_builder(build_cmd=None, npm=npm, force=True)

        def post_develop(*args, **kwargs):
            builder(*args, **kwargs)
            try:
                import pre_commit
            except ImportError:
                print(
                    "Please install pre-commit and the associated hooks; using the following commands:"
                )
                print("pip install pre-commit")
                print("python -m pre_commit install")
                print("python -m pre_commit install --hook-type pre-push")

            else:
                try:
                    subprocess.run([sys.executable, "-m", "pre_commit", "install"])
                    subprocess.run(
                        [sys.executable, "-m", "pre_commit", "install", "--hook-type", "pre-push"]
                    )
                except Exception:
                    # no-op
                    pass

        cmdclass = wrap_installers(
            post_develop=post_develop, post_dist=post_dist, ensured_targets=ensured_targets
        )
    else:
        cmdclass = wrap_installers(post_dist=post_dist, ensured_targets=ensured_targets)

    setup_args = dict(
        cmdclass=cmdclass,
        data_files=get_data_files(data_files_spec)
    )
except ImportError:
    setup_args = dict()


if __name__ == "__main__":
    setup(**setup_args)
